RtcRemoteInboundRtpStreamStats class

Statistics for the remote endpoint's inbound RTP stream corresponding to an outbound stream that is currently sent with RTCPeerConnection object.

It is measured at the remote endpoint and reported in a RTCP Receiver Report (RR) or RTCP Extended Report (XR).

Inheritance
Annotations
  • @JsonSerializable.new(createFactory: false, includeIfNull: false)

Constructors

RtcRemoteInboundRtpStreamStats({int? ssrc, String? kind, String? transportId, String? codecId, int? packetsReceived, int? packetsReceivedWithEct1, int? packetsReceivedWithCe, int? packetsReportedAsLost, int? packetsReportedAsLostButRecovered, int? packetsLost, double? jitter, String? localId, double? roundTripTime, double? totalRoundTripTime, double? fractionLost, int? roundTripTimeMeasurements, int? packetsWithBleachedEct1Marking})

Properties

codecId String?
Unique identifier that is associated to the object that was inspected to produce the RtcCodecStats associated with this RTP stream.
getter/setter pairinherited
fractionLost double?
Fraction packet loss reported for this SSRC.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
jitter double?
Packet jitter measured in seconds for this SSRC.
getter/setter pairinherited
kind String?
Either audio or video.
getter/setter pairinherited
localId String?
Identifier of the local RtcOutboundRtpStreamStats object for the same SSRC.
getter/setter pair
packetsLost int?
Total number of RTP packets lost for this SSRC.
getter/setter pairinherited
packetsReceived int?
Total number of RTP packets received for this SSRC.
getter/setter pairinherited
packetsReceivedWithCe int?
Total number of RTP packets received for this SSRC marked with the CE marking.
getter/setter pairinherited
packetsReceivedWithEct1 int?
Total number of RTP packets received for this SSRC marked with the ECT(1) marking.
getter/setter pairinherited
packetsReportedAsLost int?
Total number of RTP packets for which an RFC8888 Section 3.1 report has been sent with a zero R bit.
getter/setter pairinherited
packetsReportedAsLostButRecovered int?
Total number of RTP packets for which an RFC8888 Section 3.1 report has been sent with a zero R bit, but a later report for the same packet has the R bit set to 1.
getter/setter pairinherited
packetsWithBleachedEct1Marking int?
Number of packets that were sent with ECT(1) markings per RFC3168 Section 3, but where an RFC8888 report gave information that the packet was received with a marking of "not-ECT".
getter/setter pair
roundTripTime double?
Estimated round trip time for this SSRC based on the RTCP timestamps in the RTCP Receiver Report (RR) and measured in seconds.
getter/setter pair
roundTripTimeMeasurements int?
Total number of RTCP RR blocks received for this SSRC that contain a valid round trip time.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ssrc int?
Synchronization source (SSRC) identifier is an unsigned integer value per RFC3550 used to identify the stream of RTP packets that this stats object is describing.
getter/setter pairinherited
totalRoundTripTime double?
Cumulative sum of all round trip time measurements in seconds since the beginning of the session.
getter/setter pair
transportId String?
Unique identifier that is associated to the object that was inspected to produce the RtcTransportStats associated with this RTP stream.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited
type() RtcStatsType
Returns an RtcStatsType of this RtcStat.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromFFI(RtcStatsType_RtcRemoteInboundRtpStreamStats stats) RtcRemoteInboundRtpStreamStats
Creates RtcRemoteInboundRtpStreamStats basing on the ffi.RtcStatsType_RtcRemoteInboundRtpStreamStats received from the native side.
override
fromMap(dynamic stats) RtcRemoteInboundRtpStreamStats
Creates RtcRemoteInboundRtpStreamStats basing on the Map received from the native side.
override