RtcTransportStats class
Transport statistics related to the RTCPeerConnection object.
Constructors
- RtcTransportStats({int? packetsSent, int? packetsReceived, int? bytesSent, int? bytesReceived, RtcIceRole? iceRole, String? iceLocalUsernameFragment, RtcIceTransportState? iceState, RtcDtlsTransportState? dtlsState, String? selectedCandidatePairId, String? localCertificateId, String? remoteCertificateId, String? tlsVersion, String? dtlsCipher, RtcDtlsRole? dtlsRole, String? srtpCipher, int? ccfbMessagesSent, int? ccfbMessagesReceived, int? selectedCandidatePairChanges})
Properties
- bytesReceived ↔ int?
-
Total number of payload bytes received on the underlying
RTCIceTransport, i.e. not including headers, padding or ICE
connectivity checks.
getter/setter pair
- bytesSent ↔ int?
-
Total number of payload bytes sent on the underlying RTCIceTransport,
i.e. not including headers, padding or ICE connectivity checks.
getter/setter pair
- ccfbMessagesReceived ↔ int?
-
Number of Transport-Layer Feedback Messages of type
CongestionControl Feedback Packet, as described in RFC8888 Section 3.1, received on the transport.getter/setter pair - ccfbMessagesSent ↔ int?
-
Number of Transport-Layer Feedback Messages of type
CongestionControl Feedback Packet, as described in RFC8888 Section 3.1, sent on the transport.getter/setter pair - dtlsCipher ↔ String?
-
Descriptive name of the cipher suite used for the DTLS transport, as
defined in the
"Description" column of the IANA cipher suite registry.
getter/setter pair
- dtlsRole ↔ RtcDtlsRole?
-
RtcDtlsRole.client or RtcDtlsRole.server depending on the DTLS role.
getter/setter pair
- dtlsState ↔ RtcDtlsTransportState?
-
Current value of the state` attribute of the RTCDtlsTransport.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- iceLocalUsernameFragment ↔ String?
-
Current value of the local username fragment used in message validation
procedures RFC5245 for the underlying RTCIceTransport.
getter/setter pair
- iceRole ↔ RtcIceRole?
-
Current value of the role` attribute of the underlying
RTCIceTransport.
getter/setter pair
- iceState ↔ RtcIceTransportState?
-
Current value of the state` attribute of the underlying
RTCIceTransport.
getter/setter pair
- localCertificateId ↔ String?
-
Identified of the local certificate for components where DTLS is
negotiated.
getter/setter pair
- packetsReceived ↔ int?
-
Total number of packets received on the transport.
getter/setter pair
- packetsSent ↔ int?
-
Total number of packets sent over the transport.
getter/setter pair
- remoteCertificateId ↔ String?
-
Identified of the remote certificate for components where DTLS is
negotiated.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedCandidatePairChanges ↔ int?
-
Number of times that the selected candidate pair of the transport has
changed.
getter/setter pair
- selectedCandidatePairId ↔ String?
-
Unique identifier that is associated to the object that was inspected to
produce the RtcIceCandidatePairStats associated with the transport.
getter/setter pair
- srtpCipher ↔ String?
-
Descriptive name of the protection profile used for the SRTP
transport, as defined in the
"Profile" column of the IANA DTLS-SRTP protection profile registry
and described further in RFC5764.
getter/setter pair
- tlsVersion ↔ String?
-
Agreed TLS version for components where DTLS is negotiated.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
type(
) → RtcStatsType -
Returns an RtcStatsType of this RtcStat.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromFFI(
RtcStatsType_RtcTransportStats stats) → RtcTransportStats -
Creates RtcIceCandidatePairStats basing on the
ffi.RtcStatsType_RtcIceCandidatePairStatsreceived from the native side.override -
fromMap(
dynamic stats) → RtcTransportStats -
Creates RtcTransportStats basing on the Map received from the native
side.
override